Index: /trunk/SophyaProg/Tests/Makefile
===================================================================
--- /trunk/SophyaProg/Tests/Makefile	(revision 767)
+++ /trunk/SophyaProg/Tests/Makefile	(revision 768)
@@ -15,5 +15,5 @@
 LIBF =  $(SLB)libsophya.so 
 #LIBS = -L$(SLB) -lPI -lsophya -lm 
-LIBS = -L$(SLB) -lsophya -lm 
+LIBS = -L$(SLB) -lextsophya -lsophya -lm 
 ifeq ($(MACHEROS),Linux)
 LIBS := $(LIBS) -ldl
Index: /trunk/SophyaProg/Tests/fitsServTest.cc
===================================================================
--- /trunk/SophyaProg/Tests/fitsServTest.cc	(revision 767)
+++ /trunk/SophyaProg/Tests/fitsServTest.cc	(revision 768)
@@ -9,11 +9,14 @@
 #include "spherethetaphi.h"
 #include "localmap.h"
+#include "skymapinit.h"
 
 
 int main() 
 {
+  // ----- ATTENTION -------
+  // Initialisation de Sophya
+  // A faire au debut de main()
+  SophyaInit();
 
-  //PeidaImagesInitiator imgini; 
-  //  PeidaInit();
    FitsIoServer fserv;
   int nsmax=32;
Index: /trunk/SophyaProg/Tests/sphg0.cc
===================================================================
--- /trunk/SophyaProg/Tests/sphg0.cc	(revision 767)
+++ /trunk/SophyaProg/Tests/sphg0.cc	(revision 768)
@@ -8,5 +8,6 @@
 {
   double teta,phi;
-  PeidaInit();
+  SophyaInit();
+
   int  m=32;
   SphereGorski<double> sph(m);
Index: /trunk/SophyaProg/Tests/tblitz.cc
===================================================================
--- /trunk/SophyaProg/Tests/tblitz.cc	(revision 767)
+++ /trunk/SophyaProg/Tests/tblitz.cc	(revision 768)
@@ -4,5 +4,5 @@
 #include "timing.h"
 #include "cimage.h"
-#include "outilsinit.h"
+#include "ntoolsinit.h"
 // Test des NDataBlock
 #include "ndatablock.h"
@@ -13,5 +13,5 @@
 main(int narg, char *arg[])
 {
-PeidaInit();
+SophyaInit();
 InitTim();
 
Index: /trunk/SophyaProg/Tests/testfitsio.cc
===================================================================
--- /trunk/SophyaProg/Tests/testfitsio.cc	(revision 767)
+++ /trunk/SophyaProg/Tests/testfitsio.cc	(revision 768)
@@ -9,11 +9,11 @@
 #include "spherethetaphi.h"
 #include "localmap.h"
-
+#include "skymapinit.h"
 
 int main() 
 {
 
-  //PeidaImagesInitiator imgini; 
-  //  PeidaInit();
+  SophyaInit();
+
    FitsIoServer fserv;
   int nsmax=32;
Index: /trunk/SophyaProg/Tests/tfft.cc
===================================================================
--- /trunk/SophyaProg/Tests/tfft.cc	(revision 767)
+++ /trunk/SophyaProg/Tests/tfft.cc	(revision 768)
@@ -1,11 +1,17 @@
+#include "machdefs.h"
+
 #include <math.h>
 #include <iostream.h>
 
+#include "nbrandom.h"
 #include "fftpserver.h"
 #include "fftmserver.h"
-#include "sambainit.h"
+#include "fftwserver.h"
+#include "ntoolsinit.h"
 
 #include "timing.h"
 
+
+static bool inp_typ_random = false ;  // true -> random input
 
 template <class T>
@@ -37,5 +43,10 @@
   cout << " DBG/4 outc " << outc.NElts()  << endl; 
 
-  for (int i=0; i<num ; i++){
+  if (inp_typ_random) 
+    for (int i=0; i<num ; i++){
+      ino[i] = in[i] = GauRnd(0., 1.);
+      inc[i] = complex<T> (in[i], 0.);
+    }
+  else for (int i=0; i<num ; i++){
     ino[i] = in[i] = 0.5 + cos(2*M_PI*(double)i/(double)num) 
                          + 2*sin(4*M_PI*(double)i/(double)num);
@@ -158,10 +169,11 @@
 {
 
-  PeidaInit();
+  SophyaInit();
   InitTim();   // Initializing the CPU timer
 
   if (narg < 4) {
-    cout << "tfft/ args error - \n  Usage tfft size p/P/M f/d [NPrtFC NPrt] \n" 
-	 << " p=FFTPackTest  P=FFTPack, M=FFTMayer, f=float, d=double " << endl;
+    cout << "tfft/ args error - \n  Usage tfft size px/Px/Mx/Wx f/d [NPrtFC NPrt] \n" 
+	 << " p=FFTPackTest  P=FFTPack, M=FFTMayer, W= FFTWServer" 
+         << " x=0 -> Random input - f=float, d=double " << endl;
     exit(0);
   }
@@ -169,4 +181,9 @@
   FFTPackServer fftp;
   FFTMayerServer fftm;
+
+  FFTWServer fftw;
+
+  inp_typ_random = false;
+  if (arg[2][1] == '0')  inp_typ_random = true;
 
   int sz = atoi(arg[1]);
@@ -177,4 +194,5 @@
   FFTServerInterface * ffts;
   if (*arg[2] == 'M')  ffts = fftm.Clone();
+  else if (*arg[2] == 'W')  ffts = fftw.Clone();
   else ffts = fftp.Clone();
 
Index: /trunk/SophyaProg/Tests/tnt.cc
===================================================================
--- /trunk/SophyaProg/Tests/tnt.cc	(revision 767)
+++ /trunk/SophyaProg/Tests/tnt.cc	(revision 768)
@@ -4,5 +4,5 @@
 #include <iostream.h>
 
-#include "outilsinit.h"
+#include "histinit.h"
 #include "dvlist.h"
 #include "ntuple.h"
@@ -16,5 +16,5 @@
 int main(int narg, char *arg[])
 {
-  PeidaInit();
+  SophyaInit();
   if (narg < 2) {
     cout << " tnt/Erreur arg - Usage: tnt d/n/x/X \n" 
Index: /trunk/SophyaProg/Tests/tobjio.cc
===================================================================
--- /trunk/SophyaProg/Tests/tobjio.cc	(revision 767)
+++ /trunk/SophyaProg/Tests/tobjio.cc	(revision 768)
@@ -6,7 +6,5 @@
 
 // Pour le test 
-#include "sambainit.h"
-#include "cvector.h"
-#include "matrix.h"
+#include "histinit.h"
 #include "histos.h"
 #include "histos2.h"
@@ -21,5 +19,5 @@
 {
 
-  PeidaInit();
+  SophyaInit();
 
   cout << "Hash check, OMatrix : " << hex << PIOPersist::Hash("OMatrix") << dec << endl;
Index: /trunk/SophyaProg/Tests/tspm.cc
===================================================================
--- /trunk/SophyaProg/Tests/tspm.cc	(revision 767)
+++ /trunk/SophyaProg/Tests/tspm.cc	(revision 768)
@@ -1,4 +1,4 @@
 #include <iostream.h>
-#include "sambainit.h"
+#include "skymapinit.h"
 #include "spheregorski.h"
 #include "spherethetaphi.h"
@@ -27,5 +27,5 @@
   double gmoy, gsig;
 
-  PeidaInit();
+  SophyaInit();
   InitTim();   // Initializing the CPU timer 
   if ((narg > 1) && (strcmp(arg[1],"-h") == 0) )  {
Index: /trunk/SophyaProg/Tests/tspm2.cc
===================================================================
--- /trunk/SophyaProg/Tests/tspm2.cc	(revision 767)
+++ /trunk/SophyaProg/Tests/tspm2.cc	(revision 768)
@@ -1,5 +1,5 @@
 #include <iostream.h>
 #include <math.h>
-#include "sambainit.h"
+#include "skymapinit.h"
 #include "spheregorski.h"
 #include "spherethetaphi.h"
@@ -84,5 +84,5 @@
   double gmoy=0., gsig=0.;
 
-  PeidaInit();
+  SophyaInit();
   InitTim();   // Initializing the CPU timer 
   if ((narg > 1) && (strcmp(arg[1],"-h") == 0) )  {
Index: /trunk/SophyaProg/Tests/tstndblk.cc
===================================================================
--- /trunk/SophyaProg/Tests/tstndblk.cc	(revision 767)
+++ /trunk/SophyaProg/Tests/tstndblk.cc	(revision 768)
@@ -5,5 +5,5 @@
 #include <string.h>
 #include <math.h>
-#include "outilsinit.h"
+#include "ntoolsinit.h"
 #include "pexceptions.h"
 #include "ndatablock.h"
@@ -12,5 +12,5 @@
 int main(int narg,char *arg[])
 {
-PeidaInit();
+SophyaInit();
 float x1[5] = {1.,2.,3.,4.,5.};
 float x2[5] = {10.,20.,30.,40.,50.};
Index: /trunk/SophyaProg/Tests/tsttmat.cc
===================================================================
--- /trunk/SophyaProg/Tests/tsttmat.cc	(revision 767)
+++ /trunk/SophyaProg/Tests/tsttmat.cc	(revision 768)
@@ -5,7 +5,6 @@
 #include <string.h>
 #include <math.h>
-#include "outilsinit.h"
+#include "ntoolsinit.h"
 #include "pexceptions.h"
-#include "matrix.h"
 #include "tmatrix.h"
 #include "nbrandom.h"
@@ -14,5 +13,5 @@
 int main(int narg,char *arg[])
 {
-PeidaInit();
+SophyaInit();
 r_8 v[3][4] = {{1,2,3,4},{4,5,6,5},{7,8,9,10}};
 
Index: /trunk/SophyaProg/Tests/tsttvec.cc
===================================================================
--- /trunk/SophyaProg/Tests/tsttvec.cc	(revision 767)
+++ /trunk/SophyaProg/Tests/tsttvec.cc	(revision 768)
@@ -5,7 +5,7 @@
 #include <string.h>
 #include <math.h>
-#include "outilsinit.h"
+#include "ntoolsinit.h"
 #include "pexceptions.h"
-#include "cvector.h"
+
 #include "tvector.h"
 #include "nbrandom.h"
@@ -14,5 +14,5 @@
 int main(int narg,char *arg[])
 {
-PeidaInit();
+SophyaInit();
 r_8 v[10] = {1,2,3,4,5,6,7,8,9,10};
 {

Index: /trunk/SophyaProg/Tests/fitsioGorski.cc
===================================================================
--- /trunk/SophyaProg/Tests/fitsioGorski.cc	(revision 767)
+++ /trunk/SophyaProg/Tests/fitsioGorski.cc	(revision 768)
@@ -9,11 +9,13 @@
 #include "nbrandom.h"
 #include "fitsioserver.h" 
+#include "skymapinit.h"
+
 int main()
 {
 
   // ----- ATTENTION -------
   // Initialisation de Peida
   // A faire au debut de main()
-  PeidaInit();
+  SophyaInit();
 
   int m=4;
@@ -9,11 +9,13 @@
 
   // ----- ATTENTION -------
-  // Initialisation de Peida
+  // Initialisation de Sophya
   // A faire au debut de main()
Index: /trunk/SophyaProg/Tests/fitsioImage.cc
===================================================================
--- /trunk/SophyaProg/Tests/fitsioImage.cc	(revision 767)
+++ /trunk/SophyaProg/Tests/fitsioImage.cc	(revision 768)
@@ -7,11 +7,15 @@
 #include "nbrandom.h"
 #include "fitsioserver.h" 
+#include "skymapinit.h"
+
+
 int main()
 {
 
   // ----- ATTENTION -------
   // Initialisation de Peida
   // A faire au debut de main()
-  PeidaInit();
+  SophyaInit();
+
   ImageR4  img(20, 10);
   r_4 compt=0;
@@ -7,11 +7,15 @@
 
   // ----- ATTENTION -------
-  // Initialisation de Peida
+  // Initialisation de Sophya
   // A faire au debut de main()
Index: /trunk/SophyaProg/Tests/fitsioLocMap.cc
===================================================================
--- /trunk/SophyaProg/Tests/fitsioLocMap.cc	(revision 767)
+++ /trunk/SophyaProg/Tests/fitsioLocMap.cc	(revision 768)
@@ -8,11 +8,14 @@
 #include "nbrandom.h"
 #include "fitsioserver.h" 
+#include "skymapinit.h"
+
+
 int main()
 {
 
   // ----- ATTENTION -------
   // Initialisation de Peida
   // A faire au debut de main()
-  PeidaInit();
+  SophyaInit();
 
   int nx=10;
@@ -8,11 +8,14 @@
 
   // ----- ATTENTION -------
-  // Initialisation de Peida
+  // Initialisation de Sophya
   // A faire au debut de main()
Index: /trunk/SophyaProg/Tests/fitsioSphere.cc
===================================================================
--- /trunk/SophyaProg/Tests/fitsioSphere.cc	(revision 767)
+++ /trunk/SophyaProg/Tests/fitsioSphere.cc	(revision 768)
@@ -8,11 +8,13 @@
 #include "nbrandom.h"
 #include "fitsioserver.h" 
+#include "skymapinit.h"
+
 int main()
 {
 
   // ----- ATTENTION -------
   // Initialisation de Peida
   // A faire au debut de main()
-  PeidaInit();
+  SophyaInit();
 
   int m=4;
@@ -8,11 +8,13 @@
 
   // ----- ATTENTION -------
-  // Initialisation de Peida
+  // Initialisation de Sophya
   // A faire au debut de main()
Index: /trunk/SophyaProg/Tests/t_scan.cc
===================================================================
--- /trunk/SophyaProg/Tests/t_scan.cc	(revision 767)
+++ /trunk/SophyaProg/Tests/t_scan.cc	(revision 768)
@@ -5,5 +5,5 @@
 #include "nbmath.h"
 // Utilisation de la classe Scan
-#include "outilsinit.h"
+#include "sambainit.h"
 #include "scan.h"
 #include "ppersist.h"
@@ -11,7 +11,8 @@
 {
   // ----- ATTENTION -------
   // Initialisation de Peida
   // A faire au debut de main()
-  PeidaInit();
+  SophyaInit();
+
   int nbpix;
   float teta,phi;
@@ -11,7 +11,8 @@
 {
   // ----- ATTENTION -------
-  // Initialisation de Peida
+  // Initialisation de Sophya
   // A faire au debut de main()
Index: /trunk/SophyaProg/Tests/timg.cc
===================================================================
--- /trunk/SophyaProg/Tests/timg.cc	(revision 767)
+++ /trunk/SophyaProg/Tests/timg.cc	(revision 768)
@@ -2,5 +2,5 @@
 #include <iostream.h>
 // Utilisation de la classe Image<T>
-#include "outilsinit.h"
+#include "ntoolsinit.h"
 #include "cimage.h"
 // Utilisation des generateurs aleatoires
@@ -19,7 +19,7 @@
 
 // ----- ATTENTION -------
 // Initialisation de Peida
 // A faire au debut de main()
-PeidaInit();
+SophyaInit();
 
 cout << " ........ Debut de timg.cc ....... " << endl;
@@ -19,7 +19,7 @@
 
 // ----- ATTENTION -------
-// Initialisation de Peida
+// Initialisation de Sophya
 // A faire au debut de main()